# baseweb plugin oauth protected page

> baseweb plugin providing an oauth protected page component

[![Latest Version on PyPI](https://img.shields.io/pypi/v/baseweb-plugin-oauth-protectedpage.svg)](https://pypi.python.org/pypi/baseweb-plugin-oauth-protectedpage/)
[![Supported Implementations](https://img.shields.io/pypi/pyversions/baseweb-plugin-oauth-protectedpage.svg)](https://pypi.python.org/pypi/baseweb-plugin-oauth-protectedpage/)
![Build Status](https://github.com/christophevg/baseweb-plugin-oauth-protectedpage/actions/workflows/test.yaml/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/baseweb-plugin-oauth-protectedpage/badge/?version=latest)](https://baseweb-plugin-oauth-protectedpage.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/christophevg/baseweb-plugin-oauth-protectedpage/badge.svg?branch=master)](https://coveralls.io/github/christophevg/baseweb-plugin-oauth-protectedpage?branch=master)
[![Built with PyPi Template](https://img.shields.io/badge/PyPi_Template-v0.4.2-blue.svg)](https://github.com/christophevg/pypi-template)



## Documentation

Visit [Read the Docs](https://baseweb-plugin-oauth-protectedpage.readthedocs.org) for the full documentation, including overviews and several examples.


